Clojure only.

telsos.lib.test


with-chcljmacro

(with-ch [binding ch] & body)

Takes a value from ch and binds it to binding, then evaluates body. CLJ: blocks with <!!. CLJS: uses cljs.test/async with take! callback.

Takes a value from ch and binds it to binding, then evaluates body.
CLJ: blocks with <!!. CLJS: uses cljs.test/async with take! callback.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries