(with-ch [binding ch] & body)Takes a value from ch and binds it to binding, then evaluates body. CLJ: blocks with <!!. CLJS: uses cljs.test/async with take! callback.
Takes a value from ch and binds it to binding, then evaluates body. CLJ: blocks with <!!. CLJS: uses cljs.test/async with take! callback.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |